package MegaDistro;
# This is the top-level module for MegaDistro
#
# currently it does not have any additional function

use Test::More; # version?

$VERSION = 0.02;	#the MegaDistro package version

=pod

=head1 Sorry

If you were looking for the MegaDistro documentation, try: perldoc megadistro

=cut

